==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files/l10n/fr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Le support de stockage est temporairement non disponible",
    "Storage invalid" : "Support de stockage non valable",
    "Unknown error" : "Erreur inconnue ",
    "Files" : "Fichiers",
    "All files" : "Tous les fichiers",
    "Recent" : "Récent",
    "File could not be found" : "Ce fichier n'a pu être trouvé.",
    "Home" : "Mes fichiers",
    "Close" : "Fermer",
    "Favorites" : "Favoris",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "Upload cancelled." : "Envoi annulé.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un répertoire ou d'un fichier de taille nulle",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier cible « {dir} » n'existe plus",
    "Not enough free space" : "Pas assez d'espace disponible",
    "Uploading..." : "Téléversement en cours…",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} heure{plural_s} restante{plural_s}",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minute{plural_s} restante{plural_s}",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "{seconds} seconde{plural_s} restante{plural_s}",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "D'ici quelques instants…",
    "Soon..." : "Bientôt...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "L'envoi du fichier est en cours. Quitter cette page maintenant annulera l'envoi du fichier.",
    "Actions" : "Actions",
    "Download" : "Télécharger",
    "Rename" : "Renommer",
    "Move" : "Déplacer",
    "Target folder" : "Dossier cible",
    "Delete" : "Supprimer",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Unshare" : "Ne plus partager",
    "Details" : "Détails",
    "Select" : "Sélectionner",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire n'est pas disponible. Consultez les logs ou contactez votre administrateur",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{file}\", il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "No search results in other folders for '{tag}{filter}{endtag}'" : "Aucun résultat dans d'autres dossiers n'a été trouvé pour '{tag}{filter}{endtag}'",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclus %n caché","inclus %n cachés"],
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'ajouter des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
    "New" : "Nouveau",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ou synchronisés!",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espage de stockage est plein, les fichiers ne peuvent plus être ajoutés ou synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Votre espace de stockage est presque plein ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond à '{filter}'","correspondent à '{filter}'"],
    "View in folder" : "Voir dans le dossier",
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "Copy local link" : "Copier le dossier local",
    "Folder" : "Dossier",
    "New folder" : "Nouveau dossier",
    "Upload" : "Chargement",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "Added to favorites" : "Ajouté aux favoris",
    "Removed from favorites" : "Retiré des favoris",
    "You added {file} to your favorites" : "Vous avez ajouté {file} à vos favoris",
    "You removed {file} from your favorites" : "Vous avez retiré {file} de vos favoris",
    "File changes" : "Modifications du fichier",
    "Created by {user}" : "Créé par {user}",
    "Changed by {user}" : "Modifié par {user}",
    "Deleted by {user}" : "Supprimé par {user}",
    "Restored by {user}" : "Restauré par {user}",
    "Renamed by {user}" : "Renommé par {user}",
    "Moved by {user}" : "Déplacé par {user}",
    "You created {file}" : "Vous avez créé {file}",
    "{user} created {file}" : "{user} a créé {file}",
    "{file} was created in a public folder" : "{file} a été créé dans un dossier public",
    "You changed {file}" : "Vous avez modifié {file}",
    "{user} changed {file}" : "{user} a modifié {file}",
    "You deleted {file}" : "Vous avez supprimé {file}",
    "{user} deleted {file}" : "{user} a supprimé {file}",
    "You restored {file}" : "Vous avez restauré {file}",
    "{user} restored {file}" : "{user} a restauré {file}",
    "You renamed {oldfile} to {newfile}" : "Vous avez renommé {oldfile} en {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} a renommé {oldfile} en {newfile}",
    "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fichier ou dossier a été <strong>modifié</strong> ou <strong>renommé</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nouveau fichier ou répertoire a été <strong>créé</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "Un nouveau fichier ou répertoire a été <strong>supprimé</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limiter les notifications à ce qui concerne la création et la modification de vos <strong>fichiers favoris</strong> <em>(Flux uniquement)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Un nouveau fichier ou répertoire a été <strong>restauré</strong>",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "File handling" : "Gestion de fichiers",
    "Maximum upload size" : "Taille max. d'envoi",
    "max. possible: " : "Max. possible :",
    "Save" : "Sauvegarder",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Avec PHP-FPM il peut se passer jusqu'à 5 minutes pour que les changements soient appliqués.",
    "Missing permissions to edit from here." : "Manque de permissions pour éditer à partir d'ici.",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afficher les fichiers cachés",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accéder à vos fichiers par WebDAV</a>",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Téléversement trop volumineux",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "No favorites" : "Aucun favori",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "Shared with you" : "Partagés avec vous",
    "Shared with others" : "Partagés avec d'autres",
    "Shared by link" : "Partagés par lien",
    "Tags" : "Étiquettes",
    "Deleted files" : "Fichiers supprimés",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "Storage not available" : "Support de stockage non disponible",
    "Unable to set upload directory." : "Impossible de définir le dossier de destination.",
    "Invalid Token" : "Jeton non valide",
    "No file was uploaded. Unknown error" : "Aucun fichier n'a été envoyé. Erreur inconnue",
    "There is no error, the file uploaded with success" : "Aucune erreur, le fichier a été envoyé avec succès.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Le fichier envoyé dépasse l'instruction upload_max_filesize située dans le fichier php.ini :",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier envoyé dépasse la valeur MAX_FILE_SIZE qui était spécifiée dans le formulaire HTML.",
    "The uploaded file was only partially uploaded" : "Le fichier n'a été que partiellement envoyé.",
    "No file was uploaded" : "Pas de fichier envoyé.",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Failed to write to disk" : "Erreur d'écriture sur le disque",
    "Not enough storage available" : "Trop peu d'espace de stockage disponible",
    "The target folder has been moved or deleted." : "Le dossier cible a été déplacé ou supprimé.",
    "Upload failed. Could not find uploaded file" : "L'envoi a échoué. Impossible de trouver le fichier envoyé.",
    "Upload failed. Could not get file info." : "L'envoi a échoué. Impossible d'obtenir les informations du fichier.",
    "Invalid directory." : "Dossier non valide.",
    "Total file size {size1} exceeds upload limit {size2}" : "La taille totale du fichier {size1} excède la taille maximale d'envoi {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Erreur lors de l'envoi du fichier \"{fileName}\" : {message}",
    "Could not get result from server." : "Ne peut recevoir les résultats du serveur.",
    "No entries in this folder match '{filter}'" : "Aucune entrée de ce dossier ne correspond à '{filter}'",
    "Local link" : "Dossier local",
    "{newname} already exists" : "{newname} existe déjà",
    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un répertoire a été <strong>modifié</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichier ou un répertoire a été <strong>supprimé</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fichier ou un répertoire a été <strong>restauré</strong>",
    "You created %1$s" : "Vous avez créé %1$s",
    "%2$s created %1$s" : "%2$s a créé %1$s",
    "%1$s was created in a public folder" : "%1$s a été créé dans un dossier public",
    "You changed %1$s" : "Vous avez modifié %1$s",
    "%2$s changed %1$s" : "%2$s a modifié %1$s",
    "You deleted %1$s" : "Vous avez supprimé %1$s",
    "%2$s deleted %1$s" : "%2$s a supprimé %1$s",
    "You restored %1$s" : "Vous avez restauré %1$s",
    "%2$s restored %1$s" : "%2$s a restauré %1$s",
    "Changed by %2$s" : "Modifié par %2$s",
    "Deleted by %2$s" : "Supprimé par %2$s",
    "Restored by %2$s" : "Restauré par %2$s",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accéder à vos fichiers par WebDAV</a>",
    "Cancel upload" : "Annuler le téléversement"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.3.tar.bz2: nextcloud/apps/files/l10n/fr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
    "Storage invalid" : "Support de stockage invalide",
    "Unknown error" : "Erreur inconnue ",
    "All files" : "Tous les fichiers",
    "Recent" : "Récent",
    "File could not be found" : "Fichier introuvable",
    "Home" : "Mes fichiers",
    "Close" : "Fermer",
    "Favorites" : "Favoris",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "Upload cancelled." : "Téléversement annulé.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un répertoire ou d'un fichier de taille nulle",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier cible « {dir} » n'existe plus",
    "Not enough free space" : "Espace disponible insuffisant",
    "Uploading …" : "Téléversement...",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "Actions" : "Actions",
    "Download" : "Télécharger",
    "Rename" : "Renommer",
    "Target folder" : "Dossier cible",
    "Delete" : "Supprimer",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Unshare" : "Ne plus partager",
    "Could not load info for file \"{file}\"" : "Impossible de charger les informations du fichier \"{file}\"",
    "Files" : "Fichiers",
    "Details" : "Détails",
    "Select" : "Sélectionner",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce dossier n'est pas disponible. Consultez les logs ou contactez votre administrateur",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{file}\", il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Aucun résultat dans d'autres dossiers n'a été trouvé pour  {tag}{filter}{endtag}",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclus %n masqué","inclus %n masqués"],
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
    "New" : "Nouveau",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un nom de fichier autorisé.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Votre espace de stockage est presque plein ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond à '{filter}'","correspondent à '{filter}'"],
    "View in folder" : "Afficher dans le dossier",
    "Copied!" : "Copié !",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copier lien direct (fonctionne seulement pour les utilisateurs qui ont accès a ce fichier/dossier)",
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "New folder" : "Nouveau dossier",
    "Upload file" : "Téléverser un fichier",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "Added to favorites" : "Ajouté aux favoris",
    "Removed from favorites" : "Retiré des favoris",
    "You added {file} to your favorites" : "Vous avez ajouté {file} à vos favoris",
    "You removed {file} from your favorites" : "Vous avez retiré {file} de vos favoris",
    "File changes" : "Modifications de fichiers",
    "Created by {user}" : "Créé par {user}",
    "Changed by {user}" : "Modifié par {user}",
    "Deleted by {user}" : "Supprimé par {user}",
    "Restored by {user}" : "Restauré par {user}",
    "Renamed by {user}" : "Renommé par {user}",
    "Moved by {user}" : "Déplacé par {user}",
    "\"remote user\"" : "\"utilisateur distant\"",
    "You created {file}" : "Vous avez créé {file}",
    "{user} created {file}" : "{user} a créé {file}",
    "{file} was created in a public folder" : "{file} a été créé dans un dossier public",
    "You changed {file}" : "Vous avez modifié {file}",
    "{user} changed {file}" : "{user} a modifié {file}",
    "You deleted {file}" : "Vous avez supprimé {file}",
    "{user} deleted {file}" : "{user} a supprimé {file}",
    "You restored {file}" : "Vous avez restauré {file}",
    "{user} restored {file}" : "{user} a restauré {file}",
    "You renamed {oldfile} to {newfile}" : "Vous avez renommé {oldfile} en {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} a renommé {oldfile} en {newfile}",
    "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fichier ou dossier a été <strong>modifié</strong> ou <strong>renommé</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nouveau fichier ou répertoire a été <strong>créé</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichier ou un répertoire a été <strong>supprimé</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limiter les notifications à ce qui concerne la création et la modification de vos <strong>fichiers favoris</strong> <em>(Flux uniquement)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un fichier ou un répertoire a été <strong>restauré</strong>",
    "Unlimited" : "Illimité",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "File handling" : "Gestion de fichiers",
    "Maximum upload size" : "Taille max. d'envoi",
    "max. possible: " : "Max. possible :",
    "Save" : "Enregistrer",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Avec PHP-FPM il peut se passer jusqu'à 5 minutes pour que les changements soient appliqués.",
    "Missing permissions to edit from here." : "Permissions insuffisantes pour modifier à partir d'ici.",
    "%s of %s used" : "%s de %s utilisé",
    "%s used" : "%s utilisé",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afficher les fichiers cachés",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accéder à vos fichiers par WebDAV</a>",
    "Uploading @" : "Envoi en cours @",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Téléversement trop volumineux",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "No favorites yet" : "Aucun favori pour l'instant",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "Shared with you" : "Partagés avec vous",
    "Shared with others" : "Partagés avec d'autres",
    "Shared by link" : "Partagés par lien",
    "Tags" : "Étiquettes",
    "Deleted files" : "Fichiers supprimés",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "Uploading..." : "Envoi en cours…",
    "..." : "…",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} heure restante","{hours}:{minutes}:{seconds} heures restantes"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minute restante","{minutes}:{seconds} minutes restantes"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} seconde restante","{seconds} secondes restantes"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "D'ici quelques instants…",
    "Soon..." : "Bientôt…",
    "File upload is in progress. Leaving the page now will cancel the upload." : "L'envoi du fichier est en cours. Quitter cette page maintenant annulera l'envoi du fichier.",
    "Move" : "Déplacer",
    "Copy local link" : "Copier le dossier local",
    "Folder" : "Dossier",
    "Upload" : "Téléverser",
    "A new file or folder has been <strong>deleted</strong>" : "Un nouveau fichier ou répertoire a été <strong>supprimé</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Un nouveau fichier ou répertoire a été <strong>restauré</strong>",
    "No favorites" : "Aucun favori"
},
"nplurals=2; plural=(n > 1);");
